svn commit: r324984 - head/lib/libsysdecode

Warner Losh imp at FreeBSD.org
Wed Oct 25 15:30:27 UTC 2017


Author: imp
Date: Wed Oct 25 15:30:25 2017
New Revision: 324984
URL: https://svnweb.freebsd.org/changeset/base/324984

Log:
  RB_POWERCYCLE needs to be handled like RB_POWEROFF for decoding.
  
  Sponsored by: Netflix

Modified:
  head/lib/libsysdecode/flags.c

Modified: head/lib/libsysdecode/flags.c
==============================================================================
--- head/lib/libsysdecode/flags.c	Wed Oct 25 15:30:20 2017	(r324983)
+++ head/lib/libsysdecode/flags.c	Wed Oct 25 15:30:25 2017	(r324984)
@@ -647,9 +647,9 @@ sysdecode_reboot_howto(FILE *fp, int howto, int *rem)
 	/*
 	 * RB_AUTOBOOT is special in that its value is zero, but it is
 	 * also an implied argument if a different operation is not
 	 * requested via RB_HALT, RB_POWEROFF, or RB_REROOT.
 	 */
-	if (howto != 0 && (howto & (RB_HALT | RB_POWEROFF | RB_REROOT)) == 0) {
+	if (howto != 0 && (howto & (RB_HALT | RB_POWEROFF | RB_REROOT | RB_POWERCYCLE)) == 0) {
 		fputs("RB_AUTOBOOT|", fp);
 		printed = true;
 	} else
@@ -647,9 +647,9 @@ sysdecode_reboot_howto(FILE *fp, int howto, int *rem)
 	 * RB_AUTOBOOT is special in that its value is zero, but it is
 	 * also an implied argument if a different operation is not
-	 * requested via RB_HALT, RB_POWEROFF, or RB_REROOT.
+	 * requested via RB_HALT, RB_POWERCYCLE, RB_POWEROFF, or RB_REROOT.
 	 */


More information about the svn-src-head mailing list